@@ -78,11 +78,11 @@ Gets C<sin6_scope_id>.
 
 Sets C<sin6_scope_id>.
 
-=head2 sin6_addr
+=head2 copy_sin6_addr
 
-  method sin6_addr : Sys::Socket::In6_addr ();
+  method copy_sin6_addr : Sys::Socket::In6_addr ();
 
-Gets C<sin6_addr>. This is a L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr> object.
+Copies C<sin6_addr>. This is a L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr> object.
 
 =head2 set_sin6_addr
 
